@@ -4,6 +4,13 @@ registered_resources = {}
 
 
 class RegisteredResourceMeta(type):
+    """
+    Registers resource classes in a dictionary, to make them accessible
+    dynamically through the class name.
+
+    Classes are registered by default, unless ``register_resource = False``
+    is specified at the class level.
+    """
     def __new__(mcs, name, bases, attrs):
         klass = super().__new__(mcs, name, bases, attrs)
 
